main: rename 'real_main()' to 'model_main()'
authorBrian Norris <banorris@uci.edu>
Tue, 9 Oct 2012 01:34:35 +0000 (18:34 -0700)
committerBrian Norris <banorris@uci.edu>
Tue, 9 Oct 2012 01:34:35 +0000 (18:34 -0700)
main.cc

diff --git a/main.cc b/main.cc
index 300306a461bc6c4f1f9f902239bb285567d8c493..853654ccd35626c8410842f15419b265accd2dbb 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -77,8 +77,8 @@ static void parse_options(struct model_params *params, int *argc, char ***argv)
 int main_argc;
 char **main_argv;
 
-/** The real_main function contains the main model checking loop. */
-static void real_main() {
+/** The model_main function contains the main model checking loop. */
+static void model_main() {
        thrd_t user_thread;
        struct model_params params;
 
@@ -110,12 +110,12 @@ static void real_main() {
 
 /**
  * Main function.  Just initializes snapshotting library and the
* snapshotting library calls the real_main function.
  */
 int main(int argc, char ** argv) {
        main_argc = argc;
        main_argv = argv;
 
        /* Let's jump in quickly and start running stuff */
-       initSnapshotLibrary(10000, 1024, 1024, 4000, &real_main);
+       initSnapshotLibrary(10000, 1024, 1024, 4000, &model_main);
 }
@@ -110,12 +110,12 @@ static void real_main() {
 /**
  * Main function.  Just initializes snapshotting library and the
- * snapshotting library calls the real_main function.
+ * snapshotting library calls the model_main function.
  */
 int main(int argc, char ** argv) {